@@ -64,8 +64,10 @@ struct _EogCloseConfirmationDialogPrivate
 	GList       *selected_images;
 
 	GtkTreeModel *list_store;
+	GtkCellRenderer *toggle_renderer;
 };
 
+
 #define EOG_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
 							EOG_TYPE_CLOSE_CONFIRMATION_DIALOG, \
 							EogCloseConfirmationDialogPrivate))
@@ -83,6 +85,37 @@ static void 	 set_unsaved_image 		(EogCloseConfirmationDialog *dlg,
 
 static GList 	*get_selected_imgs 		(GtkTreeModel                 *store);
 
+static GdkPixbuf *
+eog_close_confirmation_dialog_get_icon (const gchar *icon_name)
+{
+	GError *error = NULL;
+	GtkIconTheme *icon_theme;
+	GdkPixbuf *pixbuf;
+
+	icon_theme = gtk_icon_theme_get_default ();
+
+	pixbuf = gtk_icon_theme_load_icon (icon_theme,
+					   icon_name,
+					   IMAGE_COLUMN_HEIGHT,
+					   0,
+					   &error);
+
+	if (!pixbuf) {
+		g_warning ("Couldn't load icon: %s", error->message);
+		g_error_free (error);
+	}
+
+	return pixbuf;
+}
+
+static GdkPixbuf*
+get_nothumb_pixbuf (void)
+{
+	static GOnce nothumb_once = G_ONCE_INIT;
+	g_once (&nothumb_once, eog_close_confirmation_dialog_get_icon, "image-x-generic");
+	return GDK_PIXBUF (g_object_ref (nothumb_once.retval));
+}
+
 /*  Since we connect in the costructor we are sure this handler will be called 
  *  before the user ones
  */
@@ -424,8 +457,8 @@ populate_model (GtkTreeModel *store, GList *imgs)
 	{
 		EogImage *img;
 		const gchar *name;
-		GdkPixbuf *buf;
-		GdkPixbuf *buf_scaled;
+		GdkPixbuf *buf = NULL;
+		GdkPixbuf *buf_scaled = NULL;
 		int width;
 		double ratio;
 
@@ -434,9 +467,12 @@ populate_model (GtkTreeModel *store, GList *imgs)
 		name = eog_image_get_caption (img);
 		buf = eog_image_get_thumbnail (img);
 
-		ratio = IMAGE_COLUMN_HEIGHT / (double) gdk_pixbuf_get_height (buf);
-		width = (int) (gdk_pixbuf_get_width (buf) * ratio);
-		buf_scaled = gdk_pixbuf_scale_simple (buf, width, IMAGE_COLUMN_HEIGHT, GDK_INTERP_BILINEAR);
+		if (buf) {
+			ratio = IMAGE_COLUMN_HEIGHT / (double) gdk_pixbuf_get_height (buf);
+			width = (int) (gdk_pixbuf_get_width (buf) * ratio);
+			buf_scaled = gdk_pixbuf_scale_simple (buf, width, IMAGE_COLUMN_HEIGHT, GDK_INTERP_BILINEAR);
+		} else
+			buf_scaled = get_nothumb_pixbuf ();
 
 		gtk_list_store_append (GTK_LIST_STORE (store), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
@@ -447,6 +483,7 @@ populate_model (GtkTreeModel *store, GList *imgs)
 			            -1);
 
 		imgs = g_list_next (imgs);
+		g_object_unref (buf_scaled);
 	}
 }
 
@@ -492,7 +529,7 @@ create_treeview (EogCloseConfirmationDialogPrivate *priv)
 	priv->list_store = GTK_TREE_MODEL (store);
 	
 	/* Add columns */
-	renderer = gtk_cell_renderer_toggle_new ();
+	priv->toggle_renderer = renderer = gtk_cell_renderer_toggle_new ();
 	g_signal_connect (renderer, "toggled",
 			  G_CALLBACK (save_toggled), store);
 
@@ -645,3 +682,18 @@ eog_close_confirmation_dialog_get_unsaved_images (EogCloseConfirmationDialog *dl
 
 	return dlg->priv->unsaved_images;
 }
+
+void
+eog_close_confirmation_dialog_set_sensitive (EogCloseConfirmationDialog *dlg,
+					     gboolean value)
+{
+	GtkWidget *action_area;
+
+	g_return_if_fail (EOG_IS_CLOSE_CONFIRMATION_DIALOG (dlg));
+
+	action_area = gtk_dialog_get_action_area (GTK_DIALOG (dlg));
+	gtk_widget_set_sensitive (action_area, value);
+
+	if (dlg->priv->toggle_renderer)
+		gtk_cell_renderer_toggle_set_activatable (GTK_CELL_RENDERER_TOGGLE (dlg->priv->toggle_renderer), value);
+}
