@@ -151,7 +151,6 @@ pd_update_general_tab (EogPropertiesDialog *prop_dlg,
 				       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
 				       0, NULL, NULL);
 	if (file_info == NULL) {
-		mime_str = _("Unknown");
 		type_str = g_strdup (_("Unknown"));
 	} else {
 		mime_str = g_file_info_get_content_type (file_info);
@@ -202,7 +201,7 @@ eog_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
 static void
 eog_exif_set_focal_length_label (GtkWidget *w, ExifData *exif_data)
 {
-	ExifEntry *entry,*entry35mm;
+	ExifEntry *entry = NULL, *entry35mm = NULL;
 	ExifByteOrder byte_order;
 	gfloat f_val = 0.0;
 	gchar *fl_text = NULL,*fl35_text = NULL;
